@@ -6,10 +6,12 @@
 ## exposure: safe
 ## roles: [domaincontroller_master]
 
+import json
 import subprocess
 import time
 
-from univention.config_registry import handler_set
+import pytest
+
 from univention.testing import utils
 
 import samltest
@@ -18,10 +20,20 @@ import samltest
 def test_umc_session_timeout(ucr, saml_session):
     session_timeout = 10
     try:
-        handler_set([f'umc/saml/assertion-lifetime={session_timeout}', 'umc/saml/grace_time=1'])
+        ucr.handler_set([f'umc/saml/assertion-lifetime={session_timeout}', 'umc/saml/grace_time=1'])
         subprocess.check_call(['systemctl', 'restart', 'slapd.service'])
         subprocess.check_call(['/usr/share/univention-management-console/saml/update_metadata'])
-        utils.wait_for_listener_replication()
+        fqdn = ucr['umc/saml/sp-server'] if ucr.get('umc/saml/sp-server') else '%(hostname)s.%(domainname)s' % ucr
+        entity_id = f'https://{fqdn}/univention/saml/metadata'
+        ucr.get('keycloak/server/sso/fqdn') and subprocess.call([
+            'univention-keycloak',
+            'saml/sp',
+            'update',
+            '--metadata-file',
+            '/usr/share/univention-management-console/saml/sp/metadata.xml',
+            entity_id,
+            json.dumps({'attributes': {'saml.assertion.lifespan': session_timeout}}),
+        ])
         try:
             saml_session.login_with_new_session_at_IdP()
             saml_session.test_logged_in_status()
@@ -30,16 +42,10 @@ def test_umc_session_timeout(ucr, saml_session):
             subprocess.check_call(['systemctl', 'restart', 'slapd.service'])  # close ldap connections
             time.sleep(session_timeout + 10)
             for test_method in (saml_session.test_logged_in_status, saml_session.test_slapd):
-                try:
+                with pytest.raises(samltest.SamlError):
                     print(f'testing {test_method}')
                     test_method()
-                except samltest.SamlError:
-                    if saml_session.page.status_code == 401:
-                        print(f'OK: session timeout error for {test_method}')
-                    else:
-                        raise
-                else:
-                    utils.fail(f'No session timeout error for {test_method}')
+                assert saml_session.page.status_code == 401
             saml_session.login_with_existing_session_at_IdP()
             saml_session.test_logged_in_status()
             saml_session.test_slapd()
@@ -51,4 +57,12 @@ def test_umc_session_timeout(ucr, saml_session):
     finally:
         subprocess.check_call(['systemctl', 'restart', 'slapd.service'])
         subprocess.check_call(['/usr/share/univention-management-console/saml/update_metadata'])
-        utils.wait_for_listener_replication()
+        ucr.get('keycloak/server/sso/fqdn') and subprocess.call([
+            'univention-keycloak',
+            'saml/sp',
+            'update',
+            '--metadata-file',
+            '/usr/share/univention-management-console/saml/sp/metadata.xml',
+            entity_id,
+            json.dumps({'attributes': {'saml.assertion.lifespan': 300}}),
+        ])
